package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.RecordLeaveFj;

/**
 * 请假_附件Service接口
 * 
 * @author ruoyi
 * @date 2025-06-19
 */
public interface IRecordLeaveFjService 
{
    /**
     * 查询请假_附件
     * 
     * @param id 请假_附件主键
     * @return 请假_附件
     */
    public RecordLeaveFj selectRecordLeaveFjById(Long id);

    /**
     * 查询请假_附件列表
     * 
     * @param recordLeaveFj 请假_附件
     * @return 请假_附件集合
     */
    public List<RecordLeaveFj> selectRecordLeaveFjList(RecordLeaveFj recordLeaveFj);

    /**
     * 新增请假_附件
     * 
     * @param recordLeaveFj 请假_附件
     * @return 结果
     */
    public int insertRecordLeaveFj(RecordLeaveFj recordLeaveFj);

    /**
     * 修改请假_附件
     * 
     * @param recordLeaveFj 请假_附件
     * @return 结果
     */
    public int updateRecordLeaveFj(RecordLeaveFj recordLeaveFj);

    /**
     * 批量删除请假_附件
     * 
     * @param ids 需要删除的请假_附件主键集合
     * @return 结果
     */
    public int deleteRecordLeaveFjByIds(Long[] ids);

    /**
     * 删除请假_附件信息
     * 
     * @param id 请假_附件主键
     * @return 结果
     */
    public int deleteRecordLeaveFjById(Long id);
}
